<?php

if(!defined('TEMPLATEPATH')) {
	define( 'TEMPLATEPATH', get_bloginfo('stylesheet_directory'));
}

load_theme_textdomain ('darklock');

if (function_exists('register_sidebar')) {
	register_sidebar(array(
		'name'=> 'darklock',
		'id'=> 'darklock',
		'before_widget' => '<li id="%1$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2>',
		'after_title' => '</h2>',
	));
}
function darklock_series_init() {
	// create a new taxonomy
	register_taxonomy(
		'series',
		'post',
		array(
			'label' => __( 'Series', 'darklock' ),
			'sort' => true,
			'args' => array( 'orderby' => 'term_order' ),
			'rewrite' => array(  'slug' => __('series', 'darklock')  )
		)
	);
}
add_action( 'init', 'darklock_series_init' );

if ( ! function_exists( 'darklock_init' ) ) :
function darklock_init() {

	define('WARLOCK_MONTHLY_ARCHIVE_DATE_FORMAT', "F Y");

	if ( function_exists('add_editor_style') ) {
		add_editor_style('editor-style.css.php');
	}

	if ( function_exists('add_theme_support') ) {
		// Add default posts and comments RSS feed links to head
		add_theme_support( 'automatic-feed-links' );
	}

	$GLOBALS['darklock'] = new Warlock();
}
endif;

if ( is_admin() ) {
	switch ( basename($_SERVER['SCRIPT_FILENAME']) ) {
		case 'post.php':
			load_theme_textdomain ('darklock');
			add_filter( 'post_link', 'darklock_post_link' );
			break;

		case 'edit-comments.php':
			load_theme_textdomain ('darklock');
			add_filter( 'get_comment_link', 'darklock_comment_link' );
			break;
	}
}
else {
	add_action( 'after_setup_theme', 'darklock_init' );
}

function darklock_comment_link ($url) {
	$dash_index = strrpos($url, '-');
	if ( $dash_index === false ) {
		return $url;
	}
	$comment_id = substr($url,$dash_index+1);

	$hash_index = strrpos($url, '#');
	if ( $hash_index === false ) {
		return $url;
	}
	$url_without_hash = substr($url,0,$hash_index);

	return $url_without_hash.'#'.__('comment', 'darklock').'-'. $comment_id;
}
function darklock_post_link ($url) {
	$anchor = get_darklock_post_anchor();

	if ( empty($anchor) ) {
		return $url;
	}
	else {
		return $url.'#'.$anchor;
	}
}

function get_darklock_post_anchor ( $id = false ) {
	if ( !$id)
		$id = get_the_ID();

	if ( empty ($id) )
		return;

	return sprintf( __('post-%s', 'darklock'), $id);
}

class Warlock {

	public $theme;
	private $microposts_datetime_from;
	private $microposts_datetime_to;
	private $previous_micropost_date, $previous_comment_date;
	private $mainblog;

	function __construct() {

		$this->microposts_datetime_from = false;
		$this->microposts_datetime_to = false;
		$this->previous_micropost_date = false;
		$this->previous_comment_date = false;
		$this->mainblog = false;

		// Hook up theme JavaScript and CSS.
		add_action( 'wp_print_scripts', array($this, 'script') );
		add_action( 'wp_print_styles', array($this, 'style') );

		// Work around miscapitalization in translation.
		add_filter( 'get_comment_date', array( $this, 'date_ucfirst' )  );

		// Comment / ping separation based on http://sivel.net/2008/10/wp-27-comment-separation/
		add_filter( 'get_comments_number', array($this, 'comment_count'), 0 );

		// Meta description
		add_action( 'wp_head', array($this, 'meta_description') );

		// Permalink anchors
		add_filter ( 'comment_post_redirect', array($this, 'comment_post_redirect'), 10, 2 );

		// Escape title
		add_filter ( 'the_title', 'esc_attr' );

		// Hide categories unwanted by the user
		add_filter( 'posts_where' , array($this, 'posts_where') );

		add_filter( "get_previous_post_where" , array($this, 'get_nav_post_where') );
		add_filter( "get_next_post_where" , array($this, 'get_nav_post_where') );

		add_filter( 'pre_get_posts', array($this, 'feed_filter'));

// FILTTRÖI post_comments_feed_link_html
// echo apply_filters( 'post_comments_feed_link_html', "<a href='$url'>$link_text</a>", $post_id, $feed );

		// rel=prev,next,first,last link tags
		add_action('wp_head', array($this, 'meta_rel_links') );

		remove_action('wp_head', 'rsd_link');
		remove_action('wp_head', 'wlwmanifest_link');
		remove_action('wp_head', 'index_rel_link');

		// Set up theme data.
		$this->theme = get_theme_data(TEMPLATEPATH.'/style.css');

	}
	function get_nav_post_where( $where ) {
		global $wpdb, $post;
		$originalwhere = $where;
		$series = wp_get_object_terms( $post->ID, array('series') );
		if ( count($series) > 0 ) {
			foreach ($series as $serie) {

				$where .= " AND p.ID IN (SELECT $wpdb->term_relationships.object_id FROM `{$wpdb->term_relationships}` WHERE {$wpdb->term_relationships}.term_taxonomy_id = '{$serie->term_taxonomy_id}')";
				return $where;
			}			
		}

		else {
			foreach (get_categories() as $category) {
				if ($_COOKIE[$category->category_nicename.'_hidden']) {

					if ( in_category($category->category_nicename) ) {
					// If already viewing a post from a hidden category, 
					// forget about hiding altogether.
						return $originalwhere;
					}
					$where .= " AND p.ID NOT IN ( SELECT $wpdb->term_relationships.object_id FROM `{$wpdb->term_relationships}` WHERE {$wpdb->term_relationships}.term_taxonomy_id = (SELECT {$wpdb->term_taxonomy}.term_taxonomy_id FROM `{$wpdb->term_taxonomy}` WHERE {$wpdb->term_taxonomy}.term_id = {$category->term_id}) )";
				}
			}
		}

		return $where;
	}
	function feed_filter($query) {

		if ( !$query->is_feed || $query->is_category ) {
			return $query;
		}
		$cat = $query->get('cat');
		if ($cat) {
			$comma = ',';
		}
		foreach (
				array(
					__('memes', 'darklock'),
					__('programming', 'darklock'),
					__('links', 'darklock')
			)  as $unwanted ) {
			$cat = get_category_by_path( $unwanted );
			if ($cat) {
				$query->set('cat', $query->get('cat').$comma.'-'.$cat->term_id);
				$comma = ',';
			}
		}
		return $query;
	}
	function posts_where( $where ) {
		global $wpdb;
		$originalwhere = $where;

		if ( is_category() ) {
			return $originalwhere;
		}

		foreach (get_categories() as $category) {
			if ($_COOKIE[$category->category_nicename.'_hidden']) {
				if ( is_single() ) {
				// If already viewing a post from a hidden category, 
				// forget about hiding altogether.
					return $originalwhere;
				}
				$where .= " AND {$wpdb->posts}.ID NOT IN ( SELECT $wpdb->term_relationships.object_id FROM `{$wpdb->term_relationships}` WHERE {$wpdb->term_relationships}.term_taxonomy_id = (SELECT {$wpdb->term_taxonomy}.term_taxonomy_id FROM `{$wpdb->term_taxonomy}` WHERE {$wpdb->term_taxonomy}.term_id = {$category->term_id}) )";
			}
		}
		return $where;
	}

	function style() {
		wp_enqueue_style('google-web-font', 'http://fonts.googleapis.com/css?family=IM+Fell+DW+Pica', array(), '0');
		wp_enqueue_style( 'jquery-ui', 'http://ajax.googleapis.com/ajax/libs/jqueryui/1.8.14/themes/base/jquery-ui.css', array(), '0' );
		wp_enqueue_style('jquery-contextmenu-style', get_bloginfo('template_url').'/jquery.contextMenu.css', array(), '0');
		wp_enqueue_style('darklock-style', get_bloginfo('template_url').'/style.css', array(), '0');
		if ($_SERVER['SERVER_NAME'] != 'mummila.net') {
			wp_enqueue_style('paja', get_bloginfo('template_url').'/paja.css', array(), '0');
		}
	}
	function script() {
		wp_enqueue_script("jquery");
		wp_enqueue_script("jquery-cookie", get_bloginfo('template_url').'/js/jquery.cookie.js', array('jquery'), '0');
		wp_enqueue_script("jquery-contextmenu", get_bloginfo('template_url').'/js/jquery.contextMenu.js', array('jquery'), '0');
		if ( !is_singular() && !is_404() ) {
			wp_enqueue_script('jquery-form');
			wp_enqueue_script('darklock-acp', get_bloginfo('template_url').'/js/acp.js', array(), '0');
			wp_enqueue_script('acp-i18n', get_bloginfo('template_url').'/js/javascript.php', array(), '0');
			wp_enqueue_script('darklock-script', get_bloginfo('template_url').'/js/darklock.js', array('jquery', 'jquery-ui-core'), '0');
		}
	}
	function meta_description() {
		global $post;

		echo '
	<meta name="description" content="';
		if ( is_singular() ) {

			$tmp_post = $post;
			setup_postdata($post);
			$text = get_the_content();
			if ( empty($post->post_excerpt) ) {
				$text = strip_shortcodes( $text );
			        $text = str_replace(']]>', ']]&gt;', $text);
			        $text = strip_tags($text);
			        $excerpt_length = apply_filters('excerpt_length', 55);
			        $words = preg_split("/[\n\r\t ]+/", $text, $excerpt_length + 1, PREG_SPLIT_NO_EMPTY);
			        if ( count($words) > $excerpt_length ) {
			                array_pop($words);
			                $text = implode(' ', $words);
			                $text = $text . $excerpt_more;
			        } else {
			                $text = implode(' ', $words);
			        }
			}
			else {
				$text = str_replace('<!--:en-->', '', $post->post_excerpt);
				$text = str_replace('<!--:-->', '', $text);
			}
		        $text = str_replace('"', '&quote;', $text);
			echo $text;
			$post = $tmp_post;
			setup_postdata($post);

		}
		else if ( is_home() ) {
			global $paged;
			if ( is_paged() ) {
				printf( __('%1$s, page %2$s', 'darklock'), get_bloginfo( 'name' ), $paged );
			}
			else {
				printf( __('%1$s, home', 'darklock'), get_bloginfo( 'name' ) );
			}
		}
		else if ( is_archive() ) {
			printf( __('From the %s archive', 'darklock'), get_bloginfo( 'name' ) );
		}
		else {

			bloginfo( 'description' );
		}
		echo '" />
';
	}
	function comment_count( $count ) {
	        global $id;

		if ( is_admin() ) {
		        return $count;
		}

	        $comments_by_type = &separate_comments(get_comments('status=approve&post_id=' . $id));
	        return count($comments_by_type['comment']);
	}



	public function post_404() {
		global $post;
		if ( is_search() ) {
			$id = $this->get_page_ID_by_slug(__('no-search-results', 'darklock'));
		}
		else if ( is_tag() ) {
			$id = $this->get_page_ID_by_slug(__('no-tag-results', 'darklock'));
		}
		else if ( is_category() ) {
			$id = $this->get_page_ID_by_slug(__('no-category-results', 'darklock'));
		}
		else if ( is_archive() ) {
			$id = $this->get_page_ID_by_slug(__('no-archive-results', 'darklock'));
		}
		else {
			$id = $this->get_page_ID_by_slug(__('404-not-found', 'darklock'));
		}
		if (is_numeric($id)) {
			$post = get_post($id);
			setup_postdata($post);
		}
		else {
			// a quick and nasty fallback.
			?>
			<article class="single not-found">
				<header><!-- post header -->
					<h1 class="post-title"><?php _e("No posts found", 'darklock'); ?></h1>
					<section class="meta"></section>
				</header><!-- end post header -->
			</article><!-- end not-found post -->
			<?php
			return;
		}
		return $this->post_singular();
	}

	public function search() {
		global $post;
		?>
			<article <?php post_class(  ( is_singular() ? 'single' : '' )  ); ?> id="post-<?php the_ID();?>">
				<?php $this->post_header();
				the_content();
				get_search_form();
				$this->post_footer();
?>			</article><!-- end post-<?php the_ID();?> (the search page) -->
<?php
	}
	public function post_header_main() {
		global $wp_query;
		global $s;
		?>
				<header><!-- post header -->
					<h1>
						<a
							href="<?php the_permalink() ?>#<?php echo get_darklock_post_anchor(); ?>"
							id="<?php echo get_darklock_post_anchor(); ?>"
							title="<?php echo esc_attr(  strip_tags( get_the_title() )  ); ?>"
					  		rel="bookmark"><?php echo get_the_title(); ?></a>
					</h1>
					<h2 class="meta">
<?php
		$title = esc_attr(   strip_tags(  sprintf( __('Post no. %d', 'darklock'), get_the_ID() )  )   );
		$permalink = '<a href="'.get_bloginfo('url').'/?p'.(is_page() ? 'age_id' : '').'='.get_the_ID().'#'.__('post-number-', 'darklock').'-'.get_the_ID().'" title="'.$title.'" id="post-permalink-'.get_the_ID().'">#'.get_the_ID().'</a>';
		$date = get_the_time( get_option('date_format') );
		$time = get_the_time( get_option('time_format') );
		$author = get_the_author();
		$author_url = get_the_author_meta('user_url');
		if ($author_url) {
			$author_linked = '<a href="'.$author_url.'" title="'
				.__("Visit the author's homepage", 'darklock').'">'.get_the_author().'</a>';
			$author = $author_linked;
		}
		$author = '<strong>'.$author.'</strong>';
		echo sprintf(
				__('%1$s. %2$s at %3$s, by %4$s.', 'darklock'),
				$permalink,
				ucfirst($date),
				$time,
				$author
		);
		?>
					</h2>
				</header><!-- end post header -->

				<section class="content">
<?php
	}
	public function post_header_singular() {
		global $wp_query;
		global $s;
		?>
				<header><!-- post header -->
					<?php if ( is_404() ) : ?>
					<h1>
						<?php
						$searched_for = get_query_var('name');
						$searched_for = trim(  esc_html( (urldecode($searched_for)) )  );
						if ( empty($searched_for) ) {
							$searched_for = get_query_var('tag');
							$searched_for = trim(  esc_html( (urldecode($searched_for)) )  );
						}
						if ( empty($searched_for) ) {
							$searched_for = $s;
							$searched_for = trim(  esc_html( (urldecode($searched_for)) )  );
							$searched_for = ( empty($searched_for) ? __('nothing', 'darklock') : $searched_for );
						}
						$title_anchor = sanitize_title( get_bloginfo('name') );
						$home_root = get_bloginfo('url');
						if ( substr($home_root, -1) != '/' ) {
							$home_root .= '/';
						}
						$home = $home_root . '#' . $title_anchor;
						$linked_opening_tags = sprintf(
							'<a id="'.sanitize_title( get_bloginfo('name') ).'" href="%1$s" title="%2$s"><strong><cite>',
							$home,
							get_bloginfo('name')
						);
						$linked_closing_tags = '</cite></strong></a>';
						echo ucfirst( sprintf(
							__('%1$s%2$s%3$s doesn\'t yet have %4$s', 'darklock'),
							$linked_opening_tags,
							get_bloginfo('name'),
							$linked_closing_tags,
							$searched_for
						) );
						?>
					</h1>
					<?php else : ?>
					<h1>
						<?php echo ucfirst( $GLOBALS['darklock']->get_currently_browsing($tagged = true) ); ?>
					</h1>
					<?php endif; ?>
					<h2 class="meta">
<?php
		$title = esc_attr(   strip_tags(  sprintf( __('Post no. %d', 'darklock'), get_the_ID() )  )   );
		$permalink = '<a href="'.get_bloginfo('url').'/?p'.(is_page() ? 'age_id' : '').'='.get_the_ID().'#'.__('post-number-', 'darklock').'-'.get_the_ID().'" title="'.$title.'" id="post-permalink-'.get_the_ID().'">#'.get_the_ID().'</a>';
		$date = get_the_time( get_option('date_format') );
		$time = get_the_time( get_option('time_format') );
		$author = get_the_author();
		$author_url = get_the_author_meta('user_url');
		if ($author_url) {
			$author_linked = '<a href="'.$author_url.'" title="'
				.__("Visit the author's homepage", 'darklock').'">'.get_the_author().'</a>';
			$author = $author_linked;
		}
		$author = '<strong>'.$author.'</strong>';
		echo sprintf(
			__('%1$s. %2$s at %3$s, by %4$s.', 'darklock'),
			$permalink,
			ucfirst($date),
			$time,
			$author
		);
		?>
					</h2>
				</header><!-- end post header -->

				<section class="content">
<?php
	}
	public function get_first_category() {
		$classes = get_post_class();
		foreach ($classes as $class) {
			if ( substr($class,0,9) == "category-" && strlen($class) > 9) {
				return $class;
			}
		}
		return false;
	}
	public function post() {
		global $post;
		?>
			<article <?php post_class('fullpost'); ?> id="post-<?php the_ID();?>">
				<?php $this->post_header_main();
				the_content();
				if (  is_page( sanitize_title( ( get_option('category_base') ? get_option('category_base') : 'category') ) )  ) {
					$this->categories_page_categories_list();
				}
				else if (  is_page( sanitize_title( (get_option('tag_base') ? get_option('tag_base') : 'tag') ) )  ) {
					$this->tags_page_tags_list();
				}
				else if ( is_404() ) {
					get_search_form();
				}

				$this->post_footer();
?>
			</article><!-- end post-<?php the_ID();?> -->
			<?php if ( !is_singular() ) : ?>
			<section class="feedback-control alignright"><?php
				echo '<span class="feed-link">';
				post_comments_feed_link( '<small><small>•)</small></small>)' );
				echo '</span> ';
				$this->response_link();
			?></section>
			<?php endif; ?>
			<div class="clear"></div>

<?php
	}
	public function post_singular() {
		global $post;
		?>
			<article <?php post_class('single fullpost'); ?> id="post-<?php the_ID();?>">
				<?php $this->post_header_singular();
				if ( is_404() ) {
					echo $this->get_suggestions();
				}
				the_content();
				if (  is_page( sanitize_title( ( get_option('category_base') ? get_option('category_base') : 'category') ) )  ) {
					$this->categories_page_categories_list();
				}
				else if (  is_page( sanitize_title( (get_option('tag_base') ? get_option('tag_base') : 'tag') ) )  ) {
					$this->tags_page_tags_list();
				}
				else if ( is_404() ) {
					get_search_form();

				}

				$this->post_footer();
?>
			</article><!-- end post-<?php the_ID();?> -->
			<?php if ( !is_singular() ) : ?>
			<section class="feedback-control alignright"><?php
				echo '<span class="feed-link">';
				post_comments_feed_link( '<small><small>•)</small></small>)' );
				echo '</span> ';
				$this->response_link();
			?></section>
			<?php endif; ?>
			<div class="clear"></div>

<?php
	}
	public function post_footer() {
		?>
				</section><!-- end post content -->

				<footer class="clear"><!-- post footer -->
					<?php
		if( get_the_tag_list() ) {
?>

					<?php the_tags('<section class="taxonomy tags alignleft">
'.__('Tags: ', 'darklock'),',
','

					</section><!-- end tags -->');
?><?php
		}
		else {
?>


					<section class="taxonomy none alignleft">&nbsp;</section>
<?php
		}
?>
				</footer><!-- end post footer -->
<?php
	}

	public function response_link() {
		$comments_number = get_comments_number();
		$comments_url = get_permalink().'#'.__('comments', 'darklock');
		$comments_title = esc_attr( sprintf( __('Comments to %s', 'darklock'), get_the_title() ) );
		$comments_link_text = sprintf( __('Comments: %s', 'darklock'), '<span class="n-of-comments">'.$comments_number.'</span>' );
		$class = ( is_singular() ? '' : 'class="response-toggler"');
		echo '<a '.$class.' id="response-toggler-'.get_the_ID().'" href="'.$comments_url.'" title="'.$comments_title.'">'.$comments_link_text.'</a>';
	}
	public function respond_link($template = '') {
		$respond_url = get_permalink().'#'.__('respond', 'darklock');
		$respond_link_text = sprintf( __('Respond to %s', 'darklock'), get_the_title() );
		$respond_title = esc_attr( $respond_link_text );
		$class = (empty($template) ? '' : 'class="collapser" ');
		echo '<a '.$class.' id="commenting-collapser-'.get_the_ID().'" href="'.$respond_url.'" title="'.$respond_title.'">'.$respond_link_text.'</a>';
	}
	public function comments_template($template = '', $form = false) {
		global $withcomments;
		$withcomments = 1;
		?><section class="<?php echo (empty($template) ? '' : 'togglable '); ?>response" id="response-container-<?php the_ID(); ?>"><!-- BEGIN comments-<?php the_ID(); ?> --><?php
		comments_template($template, true);
		if ( !empty($template) ) :
		?><div id="commenting-form-placeholder-<?php the_ID(); ?>"><span class="respond-link-holder"><!--<?php $this->respond_link('main'); ?>--></span><?php
			if ($form) {
				$GLOBALS['darklock']->comment_form($template);
			}
		?></div><?php
		endif;
		?></section><!-- END comments-<?php the_ID(); ?> --><?php
	}

	public function comment_form($template = '') {
		global $post;
		global $user_identity, $user_ID;
		?>

		<section class="respond" id="commenting-form-container">
			<form action="<?php echo get_option('siteurl'); ?>/wp-comments-post.php" method="post" id="commentform">
				<fieldset class="<?php echo (empty($template) ? '' : 'collapsed collapsible'); ?>" id="commenting-fieldset-collapsible">
					<legend id="response-prompt">
						<span id="<?php echo __('respond', 'darklock'); ?>"><?php
						if( 'open' == $post->comment_status ) {
							$this->respond_link($template);
						}

						else {
							echo printf( __('Commenting is closed', 'darklock'), get_the_title() );
						}

						?></legend>

					<?php if( 'open' == $post->comment_status ) : ?>

					<table id="commenting-form-content">
						<thead>
							<tr><td colspan="2"><div class="cancel-comment-reply"><?php cancel_comment_reply_link(); ?></div></td></tr>
						</thead>
						<tbody>

							<tr><!-- Gravatar & Identity Headers-->
							<?php if (function_exists('gravbox')) : ?>

								<th class="gravatar"><?php _e('Your&nbsp;gravatar', 'darklock'); ?></th>
							<?php endif; ?>
								<th class="identity"><?php _e('Your identity', 'darklock'); ?></th>
							</tr>

							<tr><!-- Gravatar & Identity containers-->
							<!-- Gravatar -->
							<?php if (function_exists('gravbox')) : ?>
								<?php if ($user_ID) : ?>
								<!-- User is logged in, so use his gravatar. -->
								<td class="gravatar"><?php gravbox(); ?></td>
								<?php elseif( get_option('comment_registration') ) : ?>
								<!-- Login is required, but the user isn't logged in, so use the default 'undefined' gravatar from WP. -->
								<td class="gravatar"><?php echo get_avatar(''); ?></td>
								<?php else : ?>
								<!-- Update the gravatar according to identity. -->
								<?php
								$avatar = get_avatar('');
								$avatar = substr($avatar, strpos($avatar, "src='")+5);
								$avatar = substr($avatar, 0, strpos($avatar, "'"));
								?>
								<td id="gravboxcell" class="gravatar" style="background: url(<?php echo $avatar; ?>) no-repeat center 1em;"><?php gravbox(); ?></td>
								<?php endif; ?>
							<?php endif; ?>

								<!-- Identity -->
							<?php if ($user_ID) : ?><!-- User is logged in. -->
								<td class="you-are logged-in"><?php printf(__('You are currently logged in as <a href="%1$s">%2$s</a>. [<a href="%3$s">Log out</a>]', 'darklock'), get_option('siteurl').'/wp-admin/profile.php', $user_identity, wp_logout_url( get_permalink().'#'.__('respond', 'darklock') ) ); ?></td>

							<?php elseif( get_option('comment_registration') ) : ?><!-- User needs to log in to comment. -->
								<td class="you-are not-logged-in"><?php printf(  __('You need <a href="%s">log in</a> to post a comment.', 'darklock'), get_bloginfo('url').'/wp-login.php?redirect_to='.urlencode( get_permalink() )  ); ?>	</td>

							<?php else : ?><!-- User isn't logged in and doesn't have to. -->
								<td class="you-are">
								    <table id="comment-user-details" style="width:100%;"><tbody>
								      <tr>
									<th><label for="author"<?php if($req) echo ' class="required"'; ?>><?php printf( __('Your Name %s', 'darklock'), $req ? ' <small>'.__('(required)', 'darklock').'</small>' : '' ); ?></label></th>
									<th style="width:50%;"><label for="email"<?php if($req) echo ' class="required"';?>><?php printf( __('Your Email Address %s', 'darklock'), $req ? ' <small>'.__('(required but will not be published)', 'darklock').'</small>' : '' ); ?></label></th>
								      </tr>
								      <tr>
									<td style="width:50%;"><input style="width:97%;" type="text" name="author" id="author" value="<?php echo $comment_author; ?>" /></td>
									<td style="width:50%;"><input style="width:98%;" type="text" name="email" id="email"   value="<?php echo $comment_author_email; ?>" /></td>
								      </tr>
								      <tr>
									<th colspan="2"><label for="url"><?php _e('Your Website Address', 'darklock'); ?></label></th>
								      </tr>
								      <tr>
									<td colspan="2"><input style="width:99%;" type="text" name="url" id="url" value="<?php echo $comment_author_url; ?>" /></td>
								      </tr>
								    </tbody></table>
								</td>

							<?php endif; ?>
							</tr>

							<tr><!-- Comment Header -->
								<th class="comment-header"<?php if (function_exists('gravbox')) echo ' colspan="2"'; ?>>
									<label for="comment" class="textarea" style="margin:0 !important; padding:0 !important;"><span class="req"><?php _e('Comments <small>(required)</small>', 'darklock'); ?></span></label>
								</th>
							</tr>

							<tr><!-- Comment editor-->
								<td<?php if (function_exists('gravbox')) echo ' colspan="2"'; ?>>
									<textarea name="comment" id="comment" cols="50" rows="20"></textarea>
								</td>
							</tr>
						</tbody>
						<tfoot>
							<tr>
								<td colspan="2"><?php _e('You can use the following <abbr title="eXtensible HyperText Markup Language">XHTML</abbr> tags:', 'darklock'); ?> <code><?php echo allowed_tags(); ?></code></td>
							</tr>
							<tr>
								<td colspan="2">
									<?php do_action('comment_form', $post->ID); ?>
									<?php comment_id_fields(); ?>
									<?php
									if ( !empty($template) ) {
										$proto = ( empty($_SERVER['HTTPS']) ? 'http://' : 'https://' );
										$url = $proto.$_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
										if (strpos($url, '#') !== false) {
											$url = substr($url,0,strpos($url, '#'));
										}
										echo "<input type='hidden' name='redirect_to' id='redirect_to' value='".$url."' />";
									}
									?>
									<p id="submit-container" class="alignright"><button type="submit" id="submit"><?php _e('Submit Comment', 'darklock'); ?></button></p>
								</td>
							</tr>
						</tfoot>
					</table><!-- end respond -->
					<?php endif; ?>
				</fieldset>
			</form>
		</section>
<?php
	}

	public function list_comments($comment, $args, $depth) {

		$GLOBALS['comment'] = $comment;
		?>
		<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">

		<header id="<?php echo __('comment', 'darklock'); ?>-<?php comment_ID() ?>"><!-- comment header -->
			<?php
		$title = esc_attr(   strip_tags(  sprintf( __('Comment no. %d', 'darklock'), get_comment_ID() )  )   );
		$permalink = '<a class="comment-permalink-scroller" href="'.get_permalink().'#'.__('comment-number-', 'darklock').get_comment_ID().'" title="'.$title.'" id="'.__('comment-number-', 'darklock').get_comment_ID().'">#'.get_comment_ID().'</a>';
		$date = get_comment_time( get_option('date_format') );
		$time = get_comment_time( get_option('time_format') );
		$author = '<strong>'.get_comment_author_link().'</strong>';
		echo sprintf(
				__('%1$s. %2$s at %3$s, by %4$s.', 'darklock'),
				$permalink,
				ucfirst($date),
				$time,
				$author
		);
		?>
		</header><!-- end comment header -->

		<section class="content clear">
			<div class="comment-author alignleft"><?php echo get_avatar($comment,$size='96',$default='',$alt=get_comment_author()); ?></div>
			<div class="comment-text"><?php comment_text(); ?></div>
		</section>

		<footer><!-- comment footer -->
			<?php if ($comment->comment_approved == '0') : ?>
			<p class="is-in-moderation"><small><strong><?php _e('This comment is in moderation.', 'darklock'); ?></strong></small></p>
			<?php endif; ?>
		</footer><!-- end comment footer -->

		<br />
		<br />
		<br />

		<?php
	}

	public function list_pings($comment, $args, $depth) {
		$GLOBALS['comment'] = $comment;
		?>
		<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>"><a href="<?php
			echo htmlspecialchars(get_comment_link($comment->comment_ID ) ) ?>"
			title="<?php _e('Permanent link to this pingback', 'darklock'); ?>"><?php
			printf(__('%1$s at %2$s', 'darklock'), get_comment_date('j. F\t\a Y'), get_comment_time()) ?></a>
			| <?php printf('<cite class="comment-citation">%s</cite>', get_comment_author_link()) ?>

		<?php if ($comment->comment_approved == '0') {
			echo '<p class="moderated"><small><strong>'.__('This pingback is in moderation.', 'darklock').'</strong></small></p>';
		}
	}

	public function list_main_comments($comment, $args, $depth) {

		$GLOBALS['comment'] = $comment;
		?>
			<div class="comment"><aside <?php comment_class('main-comment'); ?> id="comment-<?php comment_ID(); ?>">
				<header>
					<h2><?php
		$title = esc_attr(   strip_tags(  sprintf( __('%$1s: %2$s', 'darklock'), get_comment_author(), $this->get_comment_attribute(get_comment_text()) )  )   );
		$permalink = '<a href="'.get_permalink().'#'.__('comment', 'darklock').'-'.get_comment_ID().'" title="'.$title.'" class="comment-permalink-scroller" id="main-comment-permalink-'.get_comment_ID().'">#'.get_comment_ID().'</a>';
		$date = get_comment_time( get_option('date_format') );
		$time = get_comment_time( get_option('time_format') );
		$author = '<strong>'.get_comment_author_link().'</strong>';
		echo sprintf(
			__('%1$s. %2$s at %3$s, by %4$s.', 'darklock'),
			$permalink,
			ucfirst($date),
			$time,
			$author
		);
		?></h2>
				</header>
				<section class="content clear"><?php comment_text() ?></section>

				<footer><!-- comment footer -->
					<?php if ($comment->comment_approved == '0') : ?>
					<p class="is-in-moderation"><small><strong><?php _e('This comment is in moderation.', 'darklock'); ?></strong></small></p>
					<?php endif; ?>
				</footer><!-- end comment footer -->

			</aside><!-- end comment-<?php comment_ID();?> -->
<?php
	}
	public function about_link() {
		global $post;
		$about = get_page_by_path( __('about', 'darklock') );
		bloginfo('url');
		echo "/".$about->post_name."/";
		$id = $this->get_page_ID_by_slug($about->post_name);
		if ($id) {
			echo "#".get_darklock_post_anchor($id);
		}
		return;
	}
	function get_post_by_path($page_path, $output = OBJECT, $post_type = 'page') {
		return get_page_by_path($page_path, $output, 'post');
	}

	// http://erikt.tumblr.com/post/278953342/get-a-wordpress-page-id-with-the-slug
	function get_page_ID_by_slug($slug) {
		$page = get_page_by_path($slug);
		if ($page) {
			return $page->ID;
		} else {
			return null;
		}
	}
	function get_ID_by_slug($slug) {

		if ( is_page() ) {
			return $this->get_page_ID_by_slug($slug);
		}

		$page = $this->get_post_by_path($slug);
		if ($page) {
			return $page->ID;
		} else {
			return null;
		}
	}
	public function comment_post_redirect ($link, $comment) {
		if ( empty($link) ) {
			return $link;
		}

		$comment_anchor = sprintf( __('comment-%s', 'darklock'), $comment->comment_ID );
		if (strpos($link, '#') !== false) {
			$link = substr($link,0,strpos($link, '#'));
		}
		return $link.'#' . $comment_anchor;
	}
	public function get_currently_browsing($tagged = true) {
		global $wp_query;
		global $s;
		if ( !get_query_var('name') && !$s ) {
			$wp_query->is_archive = true;

		}
		$currently = '';
		$title_anchor = sanitize_title( get_bloginfo('name') );
		$home_root = get_bloginfo('url');
		if ( substr($home_root, -1) != '/' ) {
			$home_root .= '/';
		}
		$home = $home_root . '#' . $title_anchor;
		$linked_opening_tags = sprintf(
			'<a id="'.sanitize_title( get_bloginfo('name') ).'" href="%1$s" title="%2$s"><strong><cite>',
			$home,
			get_bloginfo('name')
		);
		$linked_closing_tags = '</cite></strong></a>';
		if ( is_home() ) {
			if ( is_paged() ) {
				$page = $wp_query->get( 'paged' );
				$currently .= sprintf(
					__('Posts in %1$s%2$s%3$s in chronological order, page %4$s', 'darklock'),
					$linked_opening_tags,
					get_bloginfo('name'),
					$linked_closing_tags,
					$page
				);
			}
			else {
				$currently .= sprintf(
					__('The latest posts in %1$s%2$s%3$s', 'darklock'),
					$linked_opening_tags,
					get_bloginfo('name'),

					$linked_closing_tags
				);
			}
		}
		else if ( is_404() && !is_archive() ) {
			$searched_for = get_query_var('name');
			$searched_for = trim(  esc_html( (urldecode($searched_for)) )  );
			$searched_for = ( empty($searched_for) ? __('nothing', 'darklock') : $searched_for );
			$currently .= sprintf(
				__('Search results for %1$s in %2$s%3$s%4$s', 'darklock'),
				'<strong>'.$searched_for.'</strong>',
				$linked_opening_tags,
				get_bloginfo('name'),
				$linked_closing_tags
			);
		}
		else if ( is_search() ) {
			$searched_for = $s;
			$searched_for = trim(  esc_html( (urldecode($searched_for)) )  );
			$searched_for = ( empty($searched_for) ? __('nothing', 'darklock') : $searched_for );
			$currently .= sprintf(
				__('Search results for %1$s in %2$s%3$s%4$s', 'darklock'),

				'<strong>'.$searched_for.'</strong>',
				$linked_opening_tags,
				get_bloginfo('name'),
				$linked_closing_tags
			);
		}
		else if ( is_category() ) {
			$what = single_cat_title('', false);
			if ( $what == esc_attr( __('Memes', 'darklock') )  ) {
				$what = esc_attr( __('Memes in %1$s%2$s%3$s', 'darklock') );
			}
			else if (  $what == esc_attr( __('Links', 'darklock') )  ) {
				$what = esc_attr( __('Links in %1$s%2$s%3$s', 'darklock') );
			}
			else if (  $what == esc_attr( __('Pictures', 'darklock') )  ) {
				$what = esc_attr( __('Picture posts in %1$s%2$s%3$s', 'darklock') );
			}
			else if (  $what == esc_attr( __('Programming', 'darklock') )  ) {
				$what = esc_attr( __('Regular programming in %1$s%2$s%3$s', 'darklock') );
			}
			else if (  $what == esc_attr( __('Entries', 'darklock') )  ) {
				$what = esc_attr( __('Diary entries in %1$s%2$s%3$s', 'darklock') );
			}
			else {
				$what = 'wat';
			}
			if ( $what == 'wat' ) {
				$currently .= sprintf(
					__('Posts categorized %1$s in %2$s%3$s%4$s', 'darklock'),
					'<strong>'.single_cat_title('', false).'</strong>',
					$linked_opening_tags,
					get_bloginfo('name'),
					$linked_closing_tags
				);
			}
			else {
				$currently .= sprintf($what, 
					$linked_opening_tags,
					get_bloginfo('name'),
					$linked_closing_tags
				);
			}
		}
		else if ( is_tag() ) {
			$currently .= sprintf(
				__('Posts tagged %1$s from %2$s%3$s%4$s', 'darklock'),
				'<strong>'.single_tag_title('', false).'</strong>',
				$linked_opening_tags,
				get_bloginfo('name'),
				$linked_closing_tags
			);
		}
		else if (  is_tax( 'series' )  ) {
			$currently .= sprintf(
				__('Posts in series %1$s from %2$s%3$s%4$s', 'darklock'),
				'<strong>'.single_tag_title('', false).'</strong>',
				$linked_opening_tags,
				get_bloginfo('name'),
				$linked_closing_tags
			);
		}
		else if ( is_author() ) {
			global $wp_query;
			$curauth = $wp_query->get_queried_object();
			if ( empty($curauth) ) {
				$nick = $_GET['author'];
			}
			$currently .= sprintf(
				__('Posts by %1$s from %2$s%3$s%4$s', 'darklock'),
				'<strong>'.$curauth->display_name.'</strong>',
				$linked_opening_tags,
				get_bloginfo('name'),
				$linked_closing_tags
			);
		}

		else if ( is_singular() ) {

			global $wp_query;
			$post = $wp_query->get_queried_object();

			if (is_page()) {
				$what = esc_attr(
					__('a page in %1$s%2$s%3$s', 'darklock')
				);
			}
			else {
				$cats = get_the_category();
				if ( $cats ) {
					$what = $cats[0]->name;
				}
				if ( $what == esc_attr( __('Memes', 'darklock') )  ) {
					$what = esc_attr( __('a meme in %1$s%2$s%3$s', 'darklock') );
				}
				else if (  $what == esc_attr( __('Links', 'darklock') )  ) {
					$what = esc_attr( __('a link in %1$s%2$s%3$s', 'darklock') );
				}
				else if (  $what == esc_attr( __('Pictures', 'darklock') )  ) {
					$what = esc_attr( __('a picture post in %1$s%2$s%3$s', 'darklock') );
				}
				else if (  $what == esc_attr( __('Programming', 'darklock') )  ) {
					$what = esc_attr( __('a %1$s%2$s%3$s regular', 'darklock') );
				}
				else if (  $what == esc_attr( __('Entries', 'darklock') )  ) {
					$what = esc_attr( __('a diary entry in %1$s%2$s%3$s', 'darklock') );
				}
				else {
					$what = esc_attr( __('a post in %1$s%2$s%3$s', 'darklock') );
				}
			}

			$currently .= sprintf(
				__('%1$s —&nbsp;%2$s'),
				'<a
	href="'.get_permalink($post->ID).'#'.get_darklock_post_anchor().'"
	title="'.$post->post_title.'"><strong>'.$post->post_title.'</strong></a>',
				sprintf($what,
					$linked_opening_tags,
					get_bloginfo('name'),
					$linked_closing_tags
				)
			);
		}
		else {
			if ( is_404() ) {

				$d = get_query_var('day');
				$d = ( empty($d) ? 0 : (int)$d );
				$m = get_query_var('monthnum');
				$m = ( empty($m) ? 0 : (int)$m );
				$y = (int)get_query_var('year');
				$y = ( empty($y) ? 0 : (int)$y );
				setlocale(LC_TIME, get_locale() );
				if ( $d && $m && $y ) {
					$datetime = sprintf('%04d-%02d-%02d\T00:00:00', $y, $m, $d);
					$date = strftime( $this->dateFormatToStrftime( get_option('date_format') ), strtotime($datetime) );
				}
				else if ( $m && $y ) {
					$datetime = sprintf('%04d-%02d-01\T00:00:00', $y, $m);
					$date = strftime( $this->dateFormatToStrftime( WARLOCK_MONTHLY_ARCHIVE_DATE_FORMAT ), strtotime($datetime) );
					
				}
				else if ( $y ) {
					$datetime = sprintf('%04d-01-01\T00:00:00', $y);
					$date = strftime( $this->dateFormatToStrftime( __('Y', 'darklock') ), strtotime($datetime) );
				}
				else {
					$date = '';
				}
				if ( empty($date) ) {
					$currently = sprintf(
						__('The %1$s%2$s%3$s archive', 'darklock'),
						$linked_opening_tags,
						get_bloginfo('name'),
						$linked_closing_tags

					);
				}
				else {
					$currently = sprintf(
						__('The %1$s%2$s%3$s archive from %4$s', 'darklock'),
						$linked_opening_tags,
						get_bloginfo('name'),
						$linked_closing_tags,
						'<time datetime="'.$datetime.'">'.$date.'</time>'
					);
				}
			}
			else if ( is_day() ) {
				$datetime = get_the_time( 'Y-m-d\TH:i:s' );
				$date = get_the_time( get_option('date_format') );
				$currently = sprintf(
					__('The %1$s%2$s%3$s archive from %4$s', 'darklock'),
					$linked_opening_tags,
					get_bloginfo('name'),
					$linked_closing_tags,
					'<time datetime="'.$datetime.'">'.$date.'</time>'
				);
			}
			else if ( is_month() ) {
				$datetime = get_the_time( 'Y-m-d\TH:i:s' );
				$date = get_the_time( WARLOCK_MONTHLY_ARCHIVE_DATE_FORMAT );
				$currently = sprintf(
					__('The %1$s%2$s%3$s archive from %4$s', 'darklock'),
					$linked_opening_tags,
					get_bloginfo('name'),
					$linked_closing_tags,
					'<time datetime="'.$datetime.'">'.$date.'</time>'
				);
			}
			else if ( is_year() ) {
				$datetime = get_the_time( 'Y-m-d\TH:i:s' );
				$date = get_the_time( __('Y', 'darklock') );
				$currently = sprintf(

					__('The %1$s%2$s%3$s archive from %4$s', 'darklock'),
					$linked_opening_tags,
					get_bloginfo('name'),
					$linked_closing_tags,
					'<time datetime="'.$datetime.'">'.$date.'</time>'
				);
			}
		}
		if ($tagged) {
			return $currently;
		}
		else {
			return strip_tags($currently);
		}
	}
	function get_next_post_datetime_archive() {
		if ( is_year() ) {

			$current_year = (int)get_the_time('Y');
			$next_year = $current_year + 1;
			$previous_post_datetime = sprintf('%04d-01-01 00:00:00', $next_year);
		}
		else if ( is_month() ) {
			$current_year = (int)get_the_time('Y');
			$current_month = (int)get_the_time('m');
			if ($current_month >= 12) {
				$next_year = $current_year + 1;
				$next_month = 1;
				$previous_post_datetime = sprintf('%04d-%02d-01 00:00:00', $next_year, $next_month);
			}
			else {
				$next_month = $current_month + 1;
				$previous_post_datetime = sprintf('%04d-%02d-01 00:00:00', $current_year, $next_month);
			}
		}
		else if ( is_day() ) {
			$current_year = (int)get_the_time('Y');
			$current_month = (int)get_the_time('m');
			$days_this_month = cal_days_in_month(CAL_GREGORIAN, $current_month, $current_year);
			$current_day = (int)get_the_time('d');
			if ($current_day >= $days_this_month) {

				$next_day = 1;
			}
			else {
				$next_day = $current_day + 1;
				$next_month = $current_month + 1;
			}
			if ($next_month >= 12) {
				$next_month = 1;
				$next_year = $current_year + 1;
				$previous_post_datetime = sprintf('%04d-%02d-%02d 00:00:00', $next_year, $next_month, $next_day);
			}
			else {
				$previous_post_datetime = sprintf('%04d-%02d-%02d 00:00:00', $current_year, $current_month, $next_day);
			}
		}

		return $previous_post_datetime;
	}

	function microposts_limits($limit) {
		return 'LIMIT 0,'.(string)10*get_option('posts_per_page');
	}
	function get_next_post_datetime() {
		global $wpdb;

		$previous_datetime = get_the_time('Y-m-d H:i:s');

		$q = "SELECT ".$wpdb->prefix."posts.post_date FROM $wpdb->posts WHERE ".$wpdb->prefix."posts.post_status = 'publish' AND ".$wpdb->prefix."posts.post_date > '".$previous_datetime."' ORDER BY ".$wpdb->prefix."posts.post_date ASC LIMIT 0,1";

		$post = $wpdb->get_row($q, OBJECT);

		return $post->post_date;
	}			

	function get_mainblog_title() {
		$microblog = $this->get_microblog_id();
		if ( !$microblog || !$this->mainblog ) {
			return false;
		}

		switch_to_blog($this->mainblog);
		$mainblog_title = get_bloginfo('name');
		switch_to_blog($microblog);
		return $mainblog_title;
	}
	function microposts_where( $where ) {
		global $wpdb;

		$datetime_from = $this->microposts_datetime_from;
		$datetime_to = $this->microposts_datetime_to;

		if ( $datetime_from ) {
			$where .= " AND ".$wpdb->prefix."posts.post_date >= '".$datetime_from."'";

		}
		if ( $datetime_to ) {
			$where .= " AND ".$wpdb->prefix."posts.post_date < '".$datetime_to."'";

		}

		$where .= " AND ".$wpdb->prefix."posts.post_content NOT LIKE '".sprintf( __('blogged to %s', 'darklock'), $this->get_mainblog_title() )."%'";

		return $where;
	}

	function get_microblog_id() {
		if ($_SERVER['SERVER_NAME'] == 'mummila.net') {
			$microblog_path = 'kutamiiluu';
		}
		else if ($_SERVER['SERVER_NAME'] == 'mummila.kapsi.fi') {
			$microblog_path = 'askinkansi';
		}
		else {

			return false;
		}
		return get_blog_id_from_url($_SERVER['SERVER_NAME'], '/'.$microblog_path.'/');
	}
	function get_kuta_content_attribute($content) {
		$kuta_max_post_length = 140;
		$content_stripped = strip_tags( $content );
		if ( strlen ($content_stripped) > $kuta_max_post_length ) {
			$content = substr($content_stripped, 0, $kuta_max_post_length-1).'&hellip;';
		}
		else {
			$content = $content_stripped;
		}
		$colon = ( ctype_upper(substr($content,0,1)) ? ': ' : '' );
		$colon = ( empty($colon) ? ( substr($content,0,1) == ',' ? '' : ' ' ) : $colon );
		return esc_attr( strip_tags( get_the_author().$colon.$content) );
	}
	function get_comment_attribute($content) {
		$kuta_max_post_length = 140;
		$content_stripped = strip_tags( $content );
		if ( strlen ($content_stripped) > $kuta_max_post_length ) {
			$content = substr($content_stripped, 0, $kuta_max_post_length-1).'&hellip;';
		}
		else {
			$content = $content_stripped;
		}
		return esc_attr( strip_tags( $content) );
	}
	function kuta_content ($content) {
		$colon = ( ctype_upper(substr($content,0,1)) ? '<span class="segmental-colon">:</span> ' : '' );
		$colon = ( empty($colon) ? ( substr($content,0,1) == ',' ? '' : ' ' ) : $colon );
		return '<span class="author">'.get_the_author().'</span>'.$colon.$content;
	}


	function microposts($up_to_post_datetime = false) {
//print_r($_COOKIE);
		if ($_COOKIE['microposts_hidden']) {
			return;
		}

		$microblog = $this->get_microblog_id();
		if ( !$microblog ) {
			return false;
		}

		if ( is_paged() && !$up_to_post_datetime ) {
			return false;
		}

		global $post, $blog_id;
		$main_post = $post;
		$this->mainblog = $blog_id;

		$this->microposts_datetime_to = $up_to_post_datetime;

		$this->microposts_datetime_from = get_the_time('Y-m-d H:i:s');

		$darklock_date_format = get_option('date_format');
		$darklock_time_format = get_option('time_format');

		switch_to_blog($microblog);

		add_filter( 'posts_where' , array($this, 'microposts_where') );
		add_filter( 'post_limits' , array($this, 'microposts_limits') );
		$microposts_query = new WP_Query( array('status' => 'publish', ) );
		remove_filter( 'post_limits' , array($this, 'microposts_limits') );
		remove_filter( 'posts_where' , array($this, 'microposts_where') );

		if ( method_exists('Flattr', 'getInstance') ) {
			$flattr = Flattr::getInstance();
			remove_filter('the_content', array($flattr, 'injectIntoTheContent'), 32767);
		}
		else {
			$flattr = false;
		}
		remove_filter( 'the_content', 'wpautop' );
		add_filter('the_content', array($this, 'kuta_content'), 6);
		while ($microposts_query->have_posts() ) {
			$microposts_query->the_post();
		?>
			<aside class="post micropost category-microposts" id="micropost-<?php the_ID();?>">
				<h1>
					<a
						href="<?php the_permalink() ?>#<?php echo get_darklock_post_anchor(); ?>"
						id="<?php echo get_darklock_post_anchor(); ?>"
						title="<?php echo $this->get_kuta_content_attribute(get_the_content()); ?>"
				  		rel="bookmark"><?php the_content(); ?></a>
				</h1>
				<h2 class="meta">
<?php
			$title = esc_attr(   strip_tags(  sprintf( __('Micropost no. %d', 'darklock'), get_the_ID() )  )   );
			$permalink = '<a href="'.get_bloginfo('url').'/?p='.get_the_ID().'#'.__('micropost-number-', 'darklock').'-'.get_the_ID().'" title="'.$title.'" class="post-permalink-scroller" id="micropost-permalink-'.get_the_ID().'">#'.get_the_ID().'</a>';
			$date = get_the_time($darklock_date_format);
			$time = get_the_time($darklock_time_format);
			$author = get_the_author();
			$author_url = get_the_author_meta('user_url');
			if ($author_url) {
				$author_linked = '<a href="'.$author_url.'" title="'
					.__("Visit the author's homepage", 'darklock').'">'.get_the_author().'</a>';
				$author = $author_linked;
			}
			$author = '<strong>'.$author.'</strong>';
			echo sprintf(
				__('%1$s. %2$s at %3$s, by %4$s.', 'darklock'),
				$permalink,
				ucfirst($date),
				$time,
				$author
			);
			?>

				</h2>
				<?php
				$this->previous_micropost_date = get_the_time('Y-m-d');
				?>
			</aside><!-- end micropost-<?php the_ID();?> -->
	<?php
		}
		remove_filter('the_content', array($this, 'kuta_content'), 6);
		add_filter( 'the_content', 'wpautop' );
		if ( $flattr ) {
			add_filter('the_content', array($flattr, 'injectIntoTheContent'), 32767);

		}
		restore_current_blog();
		$post = $main_post;
		setup_postdata($post);
	}

	// Mimicked this from http://svn.automattic.com/wordpress/trunk/wp-includes/canonical.php
	function get_suggestions() {
		global $wpdb;
		global $s;

		// Store for re-use later.
		$name = get_query_var('name');
		if ( empty($name) )
			$name = $s;

		if ( empty($name) )
			return false;

		// if any of year, monthnum, or day are set, use them to refine the query
		if ( get_query_var('year') )
			$where_date = $wpdb->prepare(" AND YEAR(post_date) = %d", get_query_var('year'));
		if ( get_query_var('monthnum') )
			$where_date = $wpdb->prepare(" AND MONTH(post_date) = %d", get_query_var('monthnum'));
		if ( get_query_var('day') )
			$where_date = $wpdb->prepare(" AND DAYOFMONTH(post_date) = %d", get_query_var('day'));

		$where = $wpdb->prepare("post_name LIKE %s", $name . '%') .$where_date;
		$post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE $where AND post_status = 'publish'");

		if ( !$post_id ) {
			$where = $wpdb->prepare("post_name LIKE %s", '%' . $name) .$where_date;
			$post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE $where AND post_status = 'publish'");
		}
		if ( !$post_id ) {
			$where = $wpdb->prepare("post_name LIKE %s", '%' . $name . '%') .$where_date;
			$post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE $where AND post_status = 'publish'");
		}
		if ( !$post_id ) {
			$where = $wpdb->prepare("post_title LIKE %s", $name . '%') .$where_date;
			$post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE $where AND post_status = 'publish'");
		}
		if ( !$post_id ) {
			$where = $wpdb->prepare("post_title LIKE %s", '%' . $name) .$where_date;
			$post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE $where AND post_status = 'publish'");
		}
		if ( !$post_id ) {
			$where = $wpdb->prepare("post_title LIKE %s", '%' . $name . '%') .$where_date;
			$post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE $where AND post_status = 'publish'");
		}

		if ( !$post_id ) {
			return false;
		}
		return '<p class="darklock-suggestions">'
				.sprintf(__('Did you mean: %s', 'darklock'),
					'<a href="'.get_permalink($post_id)
					.'" title="'.get_the_title($post_id).'"><strong>'
					.get_the_title($post_id).'</strong></a>')
			.'</p>';
	}

	public function date_ucfirst($date) {
		return ucfirst(strtolower($date));
	}

	public function tags_page_tags_list() {
		$show_em_like_this = array(
		'smallest'  => 6, 
		'largest'   => 42,
		'unit'      => 'pt', 
		'number'    => 0,  
		'format'    => 'list',
		'separator' => '
	',
		'orderby'   => 'name', 
		'order'     => 'ASC',
//		'exclude'   => ,
//		'include'   => ,
		'link'      => 'view', 
		'taxonomy'  => 'post_tag', 
		'echo'      => true
		);

		wp_tag_cloud($show_em_like_this);
	}

	public function categories_page_categories_list() {
		$show_em_like_this = array(
//			'show_option_all'    => ,
			'orderby'            => 'name',
			'order'              => 'ASC',
			'show_last_update'   => 0,
			'style'              => 'list',
			'show_count'         => 1,
			'hide_empty'         => 1,
			'use_desc_for_title' => 1,
			'child_of'           => 0,
			'feed'               => ' <small><small>•)</small></small>) ',
//			'feed_type'          => ,
//			'feed_image'         => get_bloginfo('template_url').'/images/rss-12.png',
//			'exclude'            => ,
//			'exclude_tree'       => ,
//			'include'            => ,
			'current_category'   => 0,
			'hierarchical'       => true,
			'title_li'           => '',
			'number'             => NULL,
			'echo'               => 1,
			'depth'              => 0
		);

		echo '<ul class="all-categories">';
		wp_list_categories($show_em_like_this);
		echo '</ul>';
	}
	public function fancier_nav_between_posts($nav) {
		$nav_opening_tag_end = strpos ($nav, '">');
		$nav_closing_tag_begin = strrpos ($nav, '</');
		if ( ($nav_opening_tag_end) && ($nav_closing_tag_begin) ) {
			$nav_title_begin = $nav_opening_tag_end+2;
			$nav_title_length = $nav_closing_tag_begin-$nav_title_begin;
			$nav_title = substr($nav, $nav_title_begin, $nav_title_length);
			$nav_title = esc_attr( strip_tags($nav_title) );
			$nav_new_opening_tag = substr($nav, 0, $nav_opening_tag_end+1) . ' title="'. $nav_title .'">';
			$new_nav = $nav_new_opening_tag.esc_attr( substr($nav, $nav_title_begin, $nav_title_length) );
			$new_nav .= substr($nav, $nav_closing_tag_begin);
			$nav = $new_nav;
		}
		$nav_href_position = strpos ($nav, 'href=');
		$nav_href_begin = $nav_href_position + 6;
		$nav_href_end = strpos ($nav, '"', $nav_href_begin);
		if ($nav_href_end === false) {
			$nav_href_end = strpos ($nav, "'", $nav_href_begin);
		}
		if ($nav_href_end === false) {
			return $nav;
		}
		$new_nav = substr($nav, 0, $nav_href_end).'#nav-between-posts'.substr($nav, $nav_href_end);

		return $new_nav;
	}
	public function nav_between_posts($top = false) {

		ob_start();
		previous_post_link( __('&laquo; %link', 'darklock') );
		$ppp = ob_get_contents();
		ob_end_clean();
		if ( !empty($ppp) ) {
			$ppp = $this->fancier_nav_between('posts', $ppp);
		}

		ob_start();
		next_post_link( __('%link &raquo;', 'darklock') );
		$ppn = ob_get_contents();
		ob_end_clean();
		if ( !empty($ppn) ) {
			$ppn = $this->fancier_nav_between('posts', $ppn);
		}

		if ( !empty($ppp) || !empty($ppn) ) {
		?>

		<nav class="between posts"<?php echo ($top ? ' id="nav-between-posts"' : ''); ?>>
<?php
			if ( !empty($ppp) ) { ?>
			<span class="prev"><?php echo $ppp; ?></span>
<?php
			}
			if ( !empty($ppp) && !empty($ppn) ) { ?>
			|
<?php			}
			if ( !empty($ppn) ) { ?>
			<span class="next"><?php echo $ppn; ?></span>
<?php
			} ?>
		</nav><!-- end nav between posts -->

<?php
		}
	}
	function fancier_nav_between($something = 'posts', $nav) {
		$nav_opening_tag_end = strpos ($nav, '">');
		$nav_closing_tag_begin = strrpos ($nav, '</');
		if ( ($nav_opening_tag_end) && ($nav_closing_tag_begin) ) {
			$nav_title_begin = $nav_opening_tag_end+2;
			$nav_title_length = $nav_closing_tag_begin-$nav_title_begin;
			$nav_title = substr($nav, $nav_title_begin, $nav_title_length);
			if ( $something == 'posts' ) {
				$nav_title = esc_attr(   ucfirst(  sprintf( __('%1$s: %2$s', 'darklock'), get_bloginfo('name'),  strip_tags($nav_title) )  )   );
			}
			else {
				$nav_title = esc_attr(   ucfirst(  sprintf( __('%1$s in %2$s', 'darklock'), strip_tags($nav_title), get_bloginfo('name') )  )   );
			}
			$nav_new_opening_tag = substr($nav, 0, $nav_opening_tag_end+1) . ' title="'. $nav_title .'">';
			$new_nav = $nav_new_opening_tag.esc_attr( substr($nav, $nav_title_begin, $nav_title_length) );
			$new_nav .= substr($nav, $nav_closing_tag_begin);
			$nav = $new_nav;
		}
		$nav_href_position = strpos ($nav, 'href=');
		$nav_href_begin = $nav_href_position + 6;
		$nav_href_end = strpos ($nav, '"', $nav_href_begin);
		if ($nav_href_end === false) {
			$nav_href_end = strpos ($nav, "'", $nav_href_begin);
		}
		if ($nav_href_end === false) {
			return $nav;
		}
		$new_nav = substr($nav, 0, $nav_href_end).'#nav-between-'.$something.substr($nav, $nav_href_end);

		return $new_nav;
	}
	public function nav_between_archive_pages($top = false) {
		global $wp_query;
		ob_start();
		previous_posts_link( __('Newer posts', 'darklock') );

		$ppn = ob_get_contents();
		ob_end_clean();
		if ( !empty($ppn) ) {
			$ppn = str_replace('" >', '">', $ppn, $count = 1);
			$ppn = $this->fancier_nav_between('archive-pages', $ppn);
		}

		ob_start();
		next_posts_link( __('Older posts', 'darklock') );
		$ppo = ob_get_contents();
		ob_end_clean();
		if ( !empty($ppo) ) {
			$ppo = str_replace('" >', '">', $ppo, $count = 1);
			$ppo = $this->fancier_nav_between('archive-pages', $ppo);
		}

		if ( !empty($ppn) || !empty($ppo) ) {
			$current = ($wp_query->max_num_pages > 1 ? '<span class="currently-browsing">'.$this->get_paged_pages().'</span>' : '');
			?>
			<nav class="between archive-pages"<?php echo ($top ? ' id="nav-between-archive-pages"' : ''); ?>><?php if ( !empty($ppn) ) {
				?> <span class="prev"><?php echo '&lsaquo;&nbsp;'.$ppn; ?></span> <?php
			}
			echo $current;
			if ( !empty($ppo) ) {
				?> <span class="next"><?php echo $ppo.'&nbsp;&rsaquo;'; ?></span><?php
			}
			?>
			</nav><!-- end nav between archive-pages -->

<?php
		}
	}

	// http://www.php.net/manual/en/function.strftime.php#96424
	public static function dateFormatToStrftime($dateFormat) { 

		$caracs = array( 
			'\\a' => 'a' ,
			'\\t' => 't' ,


			// Day - no strf eq : S 
			'd' => '%d', 'D' => '%a', 'j' => '%e', 'l' => '%A', 'N' => '%u', 'w' => '%w', 'z' => '%j', 
			// Week - no date eq : %U, %W 
			'W' => '%V',  
			// Month - no strf eq : n, t 
			'F' => '%B', 'm' => '%m', 'M' => '%b', 
			// Year - no strf eq : L; no date eq : %C, %g 
			'o' => '%G', 'Y' => '%Y', 'y' => '%y', 
			// Time - no strf eq : B, G, u; no date eq : %r, %R, %T, %X 
			'a' => '%P', 'A' => '%p', 'g' => '%l', 'h' => '%I', 'H' => '%H', 'i' => '%M', 's' => '%S', 
			// Timezone - no strf eq : e, I, P, Z 
			'O' => '%z', 'T' => '%Z', 
			// Full Date / Time - no strf eq : c, r; no date eq : %c, %D, %F, %x  
			'U' => '%s' 
		); 

		return strtr((string)$dateFormat, $caracs); 
	} 

	public function get_paged_pages() {
		global $wp_query;
		global $paged;
		$paged_pages = '';
		if ($wp_query->max_num_pages > 1) {
			$page_base = 'page';
			if ($paged > 1) {
				$cp = $paged;
				$pat = '@'.$paged.'/$@';
				$paged_uri_base = preg_replace($pat, '', $_SERVER["REQUEST_URI"]);
				$unpat = '@/'.$page_base.'/'.$paged.'/$@';
				$unpaged_uri_base = preg_replace($unpat, '/', $_SERVER["REQUEST_URI"]);
			}
			else {
				$cp = 1;
				$unpaged_uri_base = $_SERVER["REQUEST_URI"];
				$paged_uri_base = $unpaged_uri_base . $page_base . '/';
			}

			$pages = array();
			$paging_limit = 5;	// keep it odd!
			$prefix = '';
			$trailer = '';
			if ($wp_query->max_num_pages > $paging_limit) {
				if ( $cp-($paging_limit / 2) < 1 ) {
					$start_from = 1;
				}
				else {
					if ($wp_query->max_num_pages - $cp-floor($paging_limit / 2) < $paging_limit) {
						$start_from = $wp_query->max_num_pages - $paging_limit +1;
					}
					else {
						$start_from = $cp-floor($paging_limit / 2);
					}

					if ($start_from > 1) {
						$prefix = '<a href="'.$unpaged_uri_base.'" title="'
							.esc_attr(  sprintf( __('Page 1 of %1$d', 'darklock'), $wp_query->max_num_pages )  ).'">1</a>&hellip;';
					}
				}
				if ( $cp+($paging_limit / 2) > $wp_query->max_num_pages ) {
					$go_until = $wp_query->max_num_pages;
				}
				else {
					if ( $cp+($paging_limit / 2) < $paging_limit ) {
						$go_until = $paging_limit;
					}
					else {
						$go_until = floor( $cp+($paging_limit / 2) );
					}

					if ($go_until < $wp_query->max_num_pages) {
						$trailer = '&hellip;<a href="'.$paged_uri_base.$wp_query->max_num_pages.'/" title="'
							.esc_attr(  sprintf( __('Page %1$d of %1$d', 'darklock'), $wp_query->max_num_pages )  ).'">'.$wp_query->max_num_pages.'</a>';
					}
				}
			}
			else {
				$start_from = 1;
				$go_until = $wp_query->max_num_pages;
			}

			if ($start_from == 1) {
				$pages[1] = '<a href="'.$unpaged_uri_base.'" title="'
						.sprintf( __('Page 1 of %1$d', 'darklock'), $wp_query->max_num_pages ).'">1</a>';
				$start_from = 2;
			}
			for ($i = $start_from; $i <= $go_until; $i++) {
				$pages[$i] = '<a href="'.$paged_uri_base.$i.'/" title="'
					.sprintf( __('Page %1$d of %2$d', 'darklock'), $i, $wp_query->max_num_pages ).'">'.$i.'</a>';
			}
			$pages[$cp] = '<span title="'.sprintf( __('Page %1$d of %2$d', 'darklock'), $cp, $wp_query->max_num_pages )
					.'" class="current-paged-page">'.$cp.'</span>';
			$paged_pages = $prefix. implode(' ', $pages) .$trailer;
		}
		return $paged_pages;
	}

	//http://guff.szub.net/meta-relationship-links/
	function meta_rel_links() {
		global $post, $wpdb;
		global $paged, $wp_query;

		if ( is_single() ) {
/*
enable if these make it to the microformats wiki or smth.

			$firstpost = @$wpdb->get_row("SELECT ID, post_title FROM $wpdb->posts WHERE post_status = 'publish' ORDER BY post_date ASC LIMIT 1");
			if($firstpost) {
				$first_title = esc_attr($firstpost->post_title);
				echo '<link rel="first" href="' . get_permalink($firstpost->ID) . '" title="' . $first_title. '" />' . "\n";
			}

			$lastpost = @$wpdb->get_row("SELECT ID, post_title FROM $wpdb->posts WHERE post_status = 'publish' ORDER BY post_date DESC LIMIT 1");
			if($lastpost) {
				$last_title = esc_attr($lastpost->post_title);
				echo '<link rel="last" href="' . get_permalink($lastpost->ID) . '" title="' . $last_title. '" />' . "\n";
			}
*/
			$post = $wp_query->post;
			$wpdb->hide_errors(); // hide errors on invalid post queries

			$prev_post = get_previous_post();
			if($prev_post) {
				$prev_title = esc_attr($prev_post->post_title);
				echo '<link rel="prev" href="' . get_permalink($prev_post->ID) . '" title="' . $prev_title. '" />' . "\n";
			}

			$next_post = get_next_post();
			if($next_post) {
				$next_title = esc_attr($next_post->post_title);
				echo '<link rel="next" href="' . get_permalink($next_post->ID) . '" title="' . $next_title. '" />' . "\n";
			}

			$wpdb->show_errors(); // turn errors back on

		}
		else {
			if ( !$paged )
				$paged = 1;

			$prevpage = intval($paged) - 1;

			if($paged > 1) {
				echo '<link rel="start" href="' . get_bloginfo('siteurl') . '/" title="'.sprintf( __('%1$s, home', 'darklock'), esc_attr(get_bloginfo('name')) ).'" />' . "\n";
				if ($paged == 2) {
					echo '<link rel="prev" href="' . get_bloginfo('siteurl') . '/" title="'.sprintf( __('%1$s, home', 'darklock'), esc_attr(get_bloginfo('name')) ).'" />' . "\n";
				}
				else {
					$url = esc_url( get_pagenum_link($prevpage) );
					echo '<link rel="prev" href="'.$url.'" title="'.sprintf( __('%1$s, page %2$s', 'darklock'), esc_attr(get_bloginfo('name')), $prevpage ).'" />' . "\n";
				}
			}
			$nextpage = intval($paged) + 1;
			$max_page = $wp_query->max_num_pages;
			if ( $nextpage <= $max_page ) {
				$url = esc_url( get_pagenum_link($nextpage) );
				echo '<link rel="next" href="'.$url.'" title="'.sprintf( __('%1$s, page %2$s', 'darklock'), esc_attr(get_bloginfo('name')), $nextpage ).'" />' . "\n";
			}
		}
	}

}
?>
